@@ -106,6 +106,20 @@ func All() []plugin.MigrationScript {
 		new(modfiyFieldsSort),
 		new(modifyIssueLeadTimeMinutesToUint),
 		new(addUrgencyToIssues),
+		new(modifyRefsIdLength),
+		new(addOriginalEnvironmentToCicdDeploymentsAndCicdDeploymentCommits),
 		new(addSubtabknameToDeployment),
+		new(addStore),
+		new(addSubtaskField),
+		new(addDisplayTitleAndUrl),
+		new(addSubtaskStates),
+		new(addCicdRelease),
+		new(addCommitShaToCicdRelease),
+		new(updateIssueKeyType),
+		new(updatePluginOptionInProjectMetricSetting),
+		new(modifyCicdDeploymentCommitsRepoUrlLength),
+		new(modifyCicdPipelineCommitsRepoUrlLength),
+		new(addPrAssigneeAndReviewer),
+		new(modifyPrAssigneeAndReviewerId),
 	}
 }
