@@ -18,10 +18,12 @@ limitations under the License.
 package api
 
 import (
+	"encoding/json"
 	"fmt"
+	"strconv"
+
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/services"
 	"github.com/apache/incubator-devlake/server/api/shared"
-	"strconv"
 
 	"github.com/apache/incubator-devlake/core/context"
 	"github.com/apache/incubator-devlake/core/dal"
@@ -90,7 +92,6 @@ func (c *ConnectionApiHelper) Patch(connection interface{}, input *plugin.ApiRes
 	if err != nil {
 		return err
 	}
-
 	err = c.merge(connection, input.Body)
 	if err != nil {
 		return err
@@ -124,10 +125,7 @@ func (c *ConnectionApiHelper) List(connections interface{}) errors.Error {
 // Delete connection.
 func (c *ConnectionApiHelper) deleteConnection(connection interface{}) (*services.BlueprintProjectPairs, errors.Error) {
 	connectionId := reflectField(connection, "ID").Uint()
-	referencingBps, err := c.bpManager.GetBlueprintsByConnection(c.pluginName, connectionId)
-	if err != nil {
-		return nil, err
-	}
+	referencingBps := c.bpManager.GetBlueprintsByConnection(c.pluginName, connectionId)
 	if len(referencingBps) > 0 {
 		return services.NewBlueprintProjectPairs(referencingBps), errors.Conflict.New("Found one or more blueprint/project references to this connection")
 	}
@@ -165,9 +163,24 @@ func (c *ConnectionApiHelper) Delete(connection interface{}, input *plugin.ApiRe
 			Success: false,
 			Message: err.Error(),
 			Data:    refs,
-		}, Status: err.GetType().GetHttpCode()}, nil
+		}, Status: err.GetType().GetHttpCode()}, err
 	}
-	return &plugin.ApiResourceOutput{Body: connection}, err
+	data, marshalErr := json.Marshal(connection)
+	if marshalErr != nil {
+		return nil, errors.Convert(marshalErr)
+	}
+	result := make(map[string]interface{})
+
+	if err := json.Unmarshal(data, &result); err != nil {
+		return nil, errors.Convert(err)
+	}
+	if _, ok := result["token"]; ok {
+		result["token"] = ""
+	}
+	return &plugin.ApiResourceOutput{Body: result}, err
+}
+func (c *ConnectionApiHelper) Merge(connection interface{}, body map[string]interface{}) errors.Error {
+	return c.merge(connection, body)
 }
 
 func (c *ConnectionApiHelper) merge(connection interface{}, body map[string]interface{}) errors.Error {
@@ -182,6 +195,10 @@ func (c *ConnectionApiHelper) merge(connection interface{}, body map[string]inte
 	return Decode(body, connection, c.validator)
 }
 
+func (c *ConnectionApiHelper) SaveWithCreateOrUpdate(connection interface{}) errors.Error {
+	return c.save(connection, c.db.CreateOrUpdate)
+}
+
 func (c *ConnectionApiHelper) save(connection interface{}, method func(entity interface{}, clauses ...dal.Clause) errors.Error) errors.Error {
 	err := CallDB(method, connection)
 	if err != nil {
