@@ -119,10 +119,13 @@ func (p Dora) MigrationScripts() []plugin.MigrationScript {
 
 func (p Dora) MakeMetricPluginPipelinePlanV200(projectName string, options json.RawMessage) (coreModels.PipelinePlan, errors.Error) {
 	op := &tasks.DoraOptions{}
-	err := json.Unmarshal(options, op)
-	if err != nil {
-		return nil, errors.Default.WrapRaw(err)
+	if options != nil && string(options) != "\"\"" {
+		err := json.Unmarshal(options, op)
+		if err != nil {
+			return nil, errors.Default.WrapRaw(err)
+		}
 	}
+
 	plan := coreModels.PipelinePlan{
 		{
 			{
