@@ -23,11 +23,9 @@ import (
 )
 
 var _ plugin.ToolLayerScope = (*SonarqubeProject)(nil)
-var _ plugin.ApiScope = (*SonarqubeApiProject)(nil)
 
 type SonarqubeProject struct {
-	common.NoPKModel `json:"-" mapstructure:"-"`
-	ConnectionId     uint64              `json:"connectionId" validate:"required" gorm:"primaryKey" mapstructure:"connectionId"`
+	common.Scope     `mapstructure:",squash"`
 	ProjectKey       string              `json:"projectKey" validate:"required" gorm:"type:varchar(255);primaryKey" mapstructure:"projectKey"`
 	Name             string              `json:"name" gorm:"type:varchar(255)" mapstructure:"name"`
 	Qualifier        string              `json:"qualifier" gorm:"type:varchar(255)" mapstructure:"qualifier"`
@@ -69,8 +67,8 @@ type SonarqubeApiProject struct {
 }
 
 // Convert the API response to our DB model instance
-func (sonarqubeApiProject SonarqubeApiProject) ConvertApiScope() plugin.ToolLayerScope {
-	sonarqubeProject := SonarqubeProject{
+func (sonarqubeApiProject *SonarqubeApiProject) ConvertApiScope() *SonarqubeProject {
+	return &SonarqubeProject{
 		ProjectKey:       sonarqubeApiProject.ProjectKey,
 		Name:             sonarqubeApiProject.Name,
 		Qualifier:        sonarqubeApiProject.Qualifier,
@@ -78,10 +76,25 @@ func (sonarqubeApiProject SonarqubeApiProject) ConvertApiScope() plugin.ToolLaye
 		LastAnalysisDate: sonarqubeApiProject.LastAnalysisDate,
 		Revision:         sonarqubeApiProject.Revision,
 	}
-	return sonarqubeProject
 }
 
 type SonarqubeApiParams struct {
 	ConnectionId uint64 `json:"connectionId"`
 	ProjectKey   string
 }
+
+type SonarqubeScopeConfig struct {
+	common.ScopeConfig
+}
+
+func (s SonarqubeScopeConfig) TableName() string {
+	return "_tool_sonarqube_scope_configs"
+}
+
+func (s SonarqubeScopeConfig) ScopeConfigId() uint64 {
+	panic("implement me")
+}
+
+func (s SonarqubeScopeConfig) ScopeConfigConnectionId() uint64 {
+	panic("implement me")
+}
