@@ -16,31 +16,18 @@
  *
  */
 
-import { Button, Intent, Position, IconName } from '@blueprintjs/core';
-import { Tooltip2 } from '@blueprintjs/popover2';
+import { forwardRef, Ref } from 'react';
+import type { ButtonProps } from 'antd';
+import { Tooltip, Button } from 'antd';
 
-interface Props {
-  style?: React.CSSProperties;
-  icon?: IconName;
-  image?: JSX.Element;
-  tooltip: string;
-  loading?: boolean;
-  disabled?: boolean;
-  onClick?: () => void;
+interface Props extends Pick<ButtonProps, 'icon' | 'type' | 'size' | 'onClick'> {
+  helptip: string;
 }
 
-export const IconButton = ({ style, icon, image, tooltip, loading, disabled, onClick }: Props) => {
+export const IconButton = forwardRef(function ({ helptip, ...props }: Props, ref?: Ref<HTMLElement>) {
   return (
-    <Tooltip2 intent={Intent.PRIMARY} position={Position.TOP} content={tooltip}>
-      <Button
-        style={style}
-        loading={loading}
-        disabled={disabled}
-        minimal
-        intent={Intent.PRIMARY}
-        icon={icon ?? image}
-        onClick={onClick}
-      />
-    </Tooltip2>
+    <Tooltip title={helptip}>
+      <Button ref={ref} {...props} />
+    </Tooltip>
   );
-};
+});
